@@ -34,24 +34,24 @@ gail_clist_cell_get_type (void)
   static GType type = 0;
 
   if (!type)
-  {
-    static const GTypeInfo tinfo =
     {
-      sizeof (GailCListCellClass),
-      (GBaseInitFunc) NULL, /* base init */
-      (GBaseFinalizeFunc) NULL, /* base finalize */
-      (GClassInitFunc) gail_clist_cell_class_init, /* class init */
-      (GClassFinalizeFunc) NULL, /* class finalize */
-      NULL, /* class data */
-      sizeof (GailCListCell), /* instance size */
-      0, /* nb preallocs */
-      (GInstanceInitFunc) NULL, /* instance init */
-      NULL /* value table */
-    };
+      static const GTypeInfo tinfo =
+      {
+        sizeof (GailCListCellClass),
+        (GBaseInitFunc) NULL, /* base init */
+        (GBaseFinalizeFunc) NULL, /* base finalize */
+        (GClassInitFunc) gail_clist_cell_class_init, /* class init */
+        (GClassFinalizeFunc) NULL, /* class finalize */
+        NULL, /* class data */
+        sizeof (GailCListCell), /* instance size */
+        0, /* nb preallocs */
+        (GInstanceInitFunc) NULL, /* instance init */
+        NULL /* value table */
+      };
 
-    type = g_type_register_static (GAIL_TYPE_CELL,
-                                   "GailCListCell", &tinfo, 0);
-  }
+      type = g_type_register_static (GAIL_TYPE_CELL,
+                                     "GailCListCell", &tinfo, 0);
+    }
   return type;
 }
 
@@ -87,27 +87,29 @@ static G_CONST_RETURN gchar*
 gail_clist_cell_get_name (AtkObject *accessible)
 {
   if (accessible->name)
-  {
     return accessible->name;
-  }
   else
-  {
-    /*
-     * Get the cell's text if it exists
-     */
-    GailCell *cell = GAIL_CELL (accessible);
-    GtkWidget* widget = cell->widget;
-    gchar *text = NULL;
-
-    if (widget == NULL)
     {
       /*
-       * State is defunct
+       * Get the cell's text if it exists
        */
-      return NULL;
+      GailCell *cell = GAIL_CELL (accessible);
+      GtkWidget* widget = cell->widget;
+      GtkCList *clist;
+      gchar *text = NULL;
+      gint row, column;
+
+      if (widget == NULL)
+        /*
+         * State is defunct
+         */
+        return NULL;
+ 
+      clist = GTK_CLIST (widget);
+      g_return_val_if_fail (clist->columns, NULL);
+      row = cell->index / clist->columns;
+      column = cell->index % clist->columns;
+      gtk_clist_get_text (clist, row, column, &text);
+      return text;
     }
-    gtk_clist_get_text (GTK_CLIST (widget), cell->row, cell->column, 
-                        &text);
-    return text;
-  }
 }
