@@ -45,24 +45,24 @@ gail_container_get_type (void)
   static GType type = 0;
 
   if (!type)
-  {
-    static const GTypeInfo tinfo =
     {
-      sizeof (GailContainerClass),
-      (GBaseInitFunc) NULL, /* base init */
-      (GBaseFinalizeFunc) NULL, /* base finalize */
-      (GClassInitFunc) gail_container_class_init, /* class init */
-      (GClassFinalizeFunc) NULL, /* class finalize */
-      NULL, /* class data */
-      sizeof (GailContainer), /* instance size */
-      0, /* nb preallocs */
-      (GInstanceInitFunc) gail_container_object_init, /* instance init */
-      NULL /* value table */
-    };
+      static const GTypeInfo tinfo =
+      {
+        sizeof (GailContainerClass),
+        (GBaseInitFunc) NULL, /* base init */
+        (GBaseFinalizeFunc) NULL, /* base finalize */
+        (GClassInitFunc) gail_container_class_init, /* class init */
+        (GClassFinalizeFunc) NULL, /* class finalize */
+        NULL, /* class data */
+        sizeof (GailContainer), /* instance size */
+        0, /* nb preallocs */
+        (GInstanceInitFunc) gail_container_object_init, /* instance init */
+        NULL /* value table */
+      };
 
-    type = g_type_register_static (GAIL_TYPE_WIDGET,
-                                    "GailContainer", &tinfo, 0);
-  }
+      type = g_type_register_static (GAIL_TYPE_WIDGET,
+                                     "GailContainer", &tinfo, 0);
+    }
 
   return type;
 }
@@ -92,33 +92,25 @@ gail_container_object_init (GailContainer      *container)
   container->children = NULL;
 }
 
-GtkAccessible* 
+AtkObject* 
 gail_container_new (GtkWidget *widget)
 {
   GObject *object;
-  GtkAccessible *accessible;
+  AtkObject *accessible;
 
   g_return_val_if_fail (GTK_IS_CONTAINER (widget), NULL);
 
   object = g_object_new (GAIL_TYPE_CONTAINER, NULL);
 
-  g_return_val_if_fail (GTK_IS_ACCESSIBLE (object), NULL);
-
   gail_widget_init (GAIL_WIDGET (object), widget);
 
-  accessible = GTK_ACCESSIBLE (object);
+  accessible = ATK_OBJECT (object);
   if (GTK_IS_TOOLBAR (widget))
-  {
-    ATK_OBJECT(accessible)->role = ATK_ROLE_TOOL_BAR;
-  }
+    accessible->role = ATK_ROLE_TOOL_BAR;
   else if (GTK_IS_VIEWPORT (widget))
-  {
-    ATK_OBJECT(accessible)->role = ATK_ROLE_VIEWPORT;
-  }
+    accessible->role = ATK_ROLE_VIEWPORT;
   else
-  {
-    ATK_OBJECT(accessible)->role = ATK_ROLE_PANEL;
-  }
+    accessible->role = ATK_ROLE_PANEL;
   return accessible;
 }
 
@@ -133,9 +125,7 @@ gail_container_get_n_children (AtkObject* obj)
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
-  {
     return count;
-  }
 
   children = gtk_container_children (GTK_CONTAINER(widget));
   count = g_list_length (children);
@@ -156,9 +146,7 @@ gail_container_ref_child (AtkObject *obj,
   g_return_val_if_fail ((i >= 0), NULL);
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
-  {
     return NULL;
-  }
 
   children = gtk_container_children (GTK_CONTAINER(widget));
   tmp_list = g_list_nth (children, i);
@@ -173,30 +161,17 @@ static gint
 gail_container_add_gtk (GtkContainer       *container,
                         GtkWidget          *widget)
 {
-  AtkPropertyValues values;
   AtkObject* atk_parent = gtk_widget_get_accessible (GTK_WIDGET (container));
   AtkObject* atk_child = gtk_widget_get_accessible (widget);
   GailContainer *gail_container = GAIL_CONTAINER (atk_parent);
   gint       index;
 
-  memset (&values.old_value, 0, sizeof (GValue));
-  memset (&values.new_value, 0, sizeof (GValue));
-
-  g_value_init (&values.new_value, G_TYPE_POINTER);
-  g_value_set_pointer (&values.new_value, atk_child);
-    
-  values.property_name = "accessible-child";
-  g_signal_emit_by_name (atk_parent, "property-change", &values, NULL);
-
-  g_value_set_pointer (&values.new_value, atk_parent);
-    
-  values.property_name = "accessible-parent";
-  g_signal_emit_by_name (atk_child, "property-change", &values, NULL);
+  g_object_notify (G_OBJECT (atk_child), "accessible_parent");
 
   g_list_free (gail_container->children);
   gail_container->children = gtk_container_children (container);
   index = g_list_index (gail_container->children, widget);
-  g_signal_emit_by_name (atk_parent, "children-changed::add", 
+  g_signal_emit_by_name (atk_parent, "children_changed::add", 
                          index, atk_child, NULL);
 
   return 1;
@@ -206,30 +181,23 @@ static gint
 gail_container_remove_gtk (GtkContainer       *container,
                            GtkWidget          *widget) 
 {
-  AtkPropertyValues values;
+  AtkPropertyValues values = { 0, };
   AtkObject *atk_parent = gtk_widget_get_accessible (GTK_WIDGET (container));
   AtkObject *atk_child = gtk_widget_get_accessible (widget);
   GailContainer *gail_container = GAIL_CONTAINER (atk_parent);
   gint       index;
 
-  memset (&values.old_value, 0, sizeof (GValue));
-  memset (&values.new_value, 0, sizeof (GValue));
-
   g_value_init (&values.old_value, G_TYPE_POINTER);
-  g_value_set_pointer (&values.old_value, atk_child);
-    
-  values.property_name = "accessible-child";
-  g_signal_emit_by_name (atk_parent, "property-change", &values, NULL);
-
   g_value_set_pointer (&values.old_value, atk_parent);
     
-  values.property_name = "accessible-parent";
-  g_signal_emit_by_name (atk_child, "property-change", &values, NULL);
+  values.property_name = "accessible_parent";
+  g_signal_emit_by_name (atk_child,
+                         "property_change::accessible_parent", &values, NULL);
 
   index = g_list_index (gail_container->children, widget);
   g_list_free (gail_container->children);
   gail_container->children = gtk_container_children (container);
-  g_signal_emit_by_name (atk_parent, "children-changed::remove", 
+  g_signal_emit_by_name (atk_parent, "children_changed::remove", 
                          index, atk_child, NULL);
 
   return 1;
@@ -245,16 +213,16 @@ gail_container_real_init (GailWidget         *widget,
   container->children = gtk_container_children (GTK_CONTAINER (gtk_widget));
 
   /*
-   * We store the handler ids for these signals as some obejcts, e.g.
+   * We store the handler ids for these signals as some objects, e.g.
    * GailButton need to remove these handlers.
    */
   container->add_handler =
-      g_signal_connect (G_OBJECT (gtk_widget),
+      g_signal_connect (gtk_widget,
                         "add",
                         G_CALLBACK (gail_container_add_gtk),
                         NULL);
   container->remove_handler =
-      g_signal_connect (G_OBJECT (gtk_widget),
+      g_signal_connect (gtk_widget,
                         "remove",
                         G_CALLBACK (gail_container_remove_gtk),
                         NULL);
