@@ -52,6 +52,9 @@ static void                  menu_item_select              (GtkItem        *item
 static void                  menu_item_deselect            (GtkItem        *item);
 static void                  menu_item_selection           (GtkItem        *item,
                                                             gboolean       selected);
+static gboolean              find_accel                    (GtkAccelKey    *key,
+                                                            GClosure       *closure,
+                                                            gpointer       data);
 
 static gpointer parent_class = NULL;
 
@@ -134,33 +137,31 @@ gail_menu_item_object_init (GailMenuItem *menu_item)
   menu_item->click_description = NULL;
 }
 
-GtkAccessible*
+AtkObject*
 gail_menu_item_new (GtkWidget *widget)
 {
   GObject *object;
-  GtkAccessible *accessible;
+  AtkObject *accessible;
 
   g_return_val_if_fail (GTK_IS_MENU_ITEM (widget), NULL);
 
   object = g_object_new (GAIL_TYPE_MENU_ITEM, NULL);
 
-  g_return_val_if_fail (GTK_IS_ACCESSIBLE (object), NULL);
-
   gail_widget_init (GAIL_WIDGET (object), widget);
 
-  accessible = GTK_ACCESSIBLE (object);
+  accessible = ATK_OBJECT (object);
 
   if (GTK_IS_TEAROFF_MENU_ITEM (widget))
-    ATK_OBJECT (accessible)->role = ATK_ROLE_TEAR_OFF_MENU_ITEM;
+    accessible->role = ATK_ROLE_TEAR_OFF_MENU_ITEM;
   else if (GTK_IS_CHECK_MENU_ITEM (widget))
     if (GTK_IS_RADIO_MENU_ITEM (widget))
-      ATK_OBJECT (accessible)->role = ATK_ROLE_RADIO_MENU_ITEM;
+      accessible->role = ATK_ROLE_RADIO_MENU_ITEM;
     else
-      ATK_OBJECT (accessible)->role = ATK_ROLE_CHECK_MENU_ITEM;
+      accessible->role = ATK_ROLE_CHECK_MENU_ITEM;
   else if (GTK_IS_SEPARATOR_MENU_ITEM (widget))
-    ATK_OBJECT (accessible)->role = ATK_ROLE_SEPARATOR;
+    accessible->role = ATK_ROLE_SEPARATOR;
   else
-    ATK_OBJECT (accessible)->role = ATK_ROLE_MENU_ITEM;
+    accessible->role = ATK_ROLE_MENU_ITEM;
 
   return accessible;
 }
@@ -325,7 +326,6 @@ gail_menu_item_get_keybinding (AtkAction *action,
       GtkWidget *temp_item;
       GtkWidget *child;
       GtkWidget *parent;
-      GSList *slist, *tmp_list;
 
       item = GTK_ACCESSIBLE (action)->widget;
       if (item == NULL)
@@ -335,7 +335,7 @@ gail_menu_item_get_keybinding (AtkAction *action,
       temp_item = item;
       while (TRUE)
         {
-          guint mnemonic_modifier = 0;
+          GdkModifierType mnemonic_modifier = 0;
           guint key_val;
           gchar *key, *temp_keybinding;
 
@@ -347,7 +347,7 @@ gail_menu_item_get_keybinding (AtkAction *action,
               return NULL;
             }
           g_return_val_if_fail (GTK_IS_ACCEL_LABEL (child), NULL);
-          parent = gtk_widget_get_parent (GTK_WIDGET (temp_item));
+          parent = gtk_widget_get_parent (temp_item);
           g_return_val_if_fail (GTK_IS_MENU_SHELL (parent), NULL);
           if (GTK_IS_MENU_BAR (parent))
             {
@@ -355,7 +355,8 @@ gail_menu_item_get_keybinding (AtkAction *action,
 
               toplevel = gtk_widget_get_toplevel (parent);
               if (toplevel && GTK_IS_WINDOW (toplevel))
-                mnemonic_modifier = GTK_WINDOW (toplevel)->mnemonic_modifier;
+                mnemonic_modifier = gtk_window_get_mnemonic_modifier (
+                                       GTK_WINDOW (toplevel));
             }
           key_val = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
           if (key_val != GDK_VoidSymbol)
@@ -375,33 +376,36 @@ gail_menu_item_get_keybinding (AtkAction *action,
               full_keybinding = NULL;
               break;
             }        
-          if (mnemonic_modifier != 0)
+          if (GTK_IS_MENU_BAR (parent))
             /* We have reached the menu bar so we are finished */
             break;
           g_return_val_if_fail (GTK_IS_MENU (parent), NULL);
           temp_item = gtk_menu_get_attach_widget (GTK_MENU (parent));
           if (!GTK_IS_MENU_ITEM (temp_item))
             {
-              /* Menu is attached to something other than a menu item  */
+              /* 
+               * Menu is attached to something other than a menu item;
+               * probably an option menu
+               */
               g_free (full_keybinding);
               full_keybinding = NULL;
               break;
             }
         }
-      slist = gtk_accel_group_entries_from_object (G_OBJECT (item));
-      for (tmp_list = slist; tmp_list; tmp_list = tmp_list->next)
+
+      parent = gtk_widget_get_parent (item);
+      if (GTK_IS_MENU (parent))
         {
-          GtkAccelEntry *accel_entry;
-          const gchar *signal_name;
+          GtkAccelGroup *group; 
+          GtkAccelKey *key;
 
-          accel_entry = tmp_list->data;
-          signal_name = g_signal_name (accel_entry->signal_id);
-
-          if (signal_name && (strcmp (signal_name, "activate") == 0))
+          group = gtk_menu_get_accel_group (GTK_MENU (parent));
+          if (group)
             {
-              accelerator = gtk_accelerator_name (accel_entry->accelerator_key,
-                                             accel_entry->accelerator_mods);
-              break;
+              key = gtk_accel_group_find (group, find_accel, item);
+
+              accelerator = gtk_accelerator_name (key->accel_key,
+                                                  key->accel_mods);
             }
         }
     }
@@ -495,3 +499,15 @@ menu_item_selection (GtkItem  *item,
   parent = atk_object_get_parent (obj);
   g_signal_emit_by_name (parent, "selection_changed"); 
 }
+
+static gboolean
+find_accel (GtkAccelKey *key,
+            GClosure    *closure,
+            gpointer     data)
+{
+  /*
+   * We assume that closure->data points to the widget
+   * pending gtk_widget_get_accel_closures being made public
+   */
+  return data == (gpointer) closure->data;
+}
