@@ -1,5 +1,6 @@
-#include <stdlib.h>
+#include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include "testlib.h" 
 
 static gint	_get_position_in_array		(gint		window,
@@ -34,8 +35,8 @@ static void	_destroy			(GtkWidget	*widget,
  **/
 AtkObject*
 find_object_by_role (AtkObject *obj,
-              AtkRole	*roles,
-	      gint      num_roles)
+                     AtkRole   *roles,
+                     gint      num_roles)
 {
   /*
    * Find the first object which is a descendant of the specified object
@@ -52,34 +53,32 @@ find_object_by_role (AtkObject *obj,
     return NULL;
 
   for (j=0; j < num_roles; j++)
-  {
-    if (atk_object_get_role (obj) == roles[j])
-      return obj;
-  }
+    {
+      if (atk_object_get_role (obj) == roles[j])
+        return obj;
+    }
 
   n_children = atk_object_get_n_accessible_children (obj);
   for (i = 0; i < n_children; i++)
-  {
-    AtkObject* found_obj;
-
-    child = atk_object_ref_accessible_child (obj, i);
-
-    if (child == NULL)
-      continue;
-
-    for (j=0; j < num_roles; j++)
     {
-      if (atk_object_get_role (child) == roles[j])
-        return child;
-    }
+      AtkObject* found_obj;
 
-    found_obj = find_object_by_role (child, roles, num_roles);
-    g_object_unref (child);
-    if (found_obj)
-    {
-      return found_obj;
+      child = atk_object_ref_accessible_child (obj, i);
+
+      if (child == NULL)
+        continue;
+
+      for (j=0; j < num_roles; j++)
+        {
+          if (atk_object_get_role (child) == roles[j])
+            return child;
+        }
+
+      found_obj = find_object_by_role (child, roles, num_roles);
+      g_object_unref (child);
+      if (found_obj)
+        return found_obj;
     }
-  }
   return NULL;
 }
 
@@ -98,10 +97,10 @@ find_object_by_role (AtkObject *obj,
  * if no object is found. 
  **/
 AtkObject*
-find_object_by_name_and_role(AtkObject *obj,
-                              const gchar *name,
-                              AtkRole	*roles,
-	                      gint      num_roles)
+find_object_by_name_and_role(AtkObject   *obj,
+                             const gchar *name,
+                             AtkRole	 *roles,
+                             gint        num_roles)
 {
   AtkObject *child;
   GtkWidget* widget;
@@ -113,46 +112,44 @@ find_object_by_name_and_role(AtkObject *obj,
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (GTK_IS_WIDGET (widget))
-  {
-    if (g_strcasecmp(name, gtk_widget_get_name(GTK_WIDGET (widget))) == 0)
     {
-      for (j=0; j < num_roles; j++)
-      {
-        if (atk_object_get_role (obj) == roles[j])
-          return obj;
-      }
+      if (g_strcasecmp(name, gtk_widget_get_name(GTK_WIDGET (widget))) == 0)
+        {
+          for (j=0; j < num_roles; j++)
+            {
+              if (atk_object_get_role (obj) == roles[j])
+                return obj;
+            }
+        }
     }
-  }
 
   n_children = atk_object_get_n_accessible_children (obj);
   for (i = 0; i < n_children; i++)
-  {
-    AtkObject* found_obj;
+    {
+      AtkObject* found_obj;
  
-    child = atk_object_ref_accessible_child (obj, i);
+      child = atk_object_ref_accessible_child (obj, i);
 
-    if (child == NULL)
-      continue;
+      if (child == NULL)
+        continue;
 
-    widget = GTK_ACCESSIBLE (child)->widget;
-    if (GTK_IS_WIDGET (widget))
-    {
-      if (g_strcasecmp(name, gtk_widget_get_name(GTK_WIDGET (widget))) == 0)
-      {
-        for (j=0; j < num_roles; j++)
+      widget = GTK_ACCESSIBLE (child)->widget;
+      if (GTK_IS_WIDGET (widget))
         {
-          if (atk_object_get_role (child) == roles[j])
-            return child;
+          if (g_strcasecmp(name, gtk_widget_get_name(GTK_WIDGET (widget))) == 0)
+            {
+              for (j=0; j < num_roles; j++)
+                {
+                  if (atk_object_get_role (child) == roles[j])
+                    return child;
+                }
+            }
         }
-      }
+      found_obj = find_object_by_name_and_role (child, name, roles, num_roles);
+      g_object_unref (child);
+      if (found_obj)
+        return found_obj;
     }
-    found_obj = find_object_by_name_and_role (child, name, roles, num_roles);
-    g_object_unref (child);
-    if (found_obj)
-    {
-      return found_obj;
-    }
-  }
   return NULL;
 }
 
@@ -172,9 +169,9 @@ find_object_by_name_and_role(AtkObject *obj,
  */
 AtkObject*
 find_object_by_accessible_name_and_role (AtkObject   *obj,
-                                          const gchar *name,
-                                          AtkRole     *roles,
-	                                  gint        num_roles)
+                                         const gchar *name,
+                                         AtkRole     *roles,
+	                                 gint        num_roles)
 {
   AtkObject *child;
   gint i, j;
@@ -186,41 +183,39 @@ find_object_by_accessible_name_and_role (AtkObject   *obj,
 
   accessible_name = atk_object_get_name (obj);
   if (accessible_name && (g_strcasecmp(name, accessible_name) == 0))
-  {
-    for (j=0; j < num_roles; j++)
     {
-      if (atk_object_get_role (obj) == roles[j])
-        return obj;
+      for (j=0; j < num_roles; j++)
+        {
+          if (atk_object_get_role (obj) == roles[j])
+            return obj;
+        }
     }
-  }
 
   n_children = atk_object_get_n_accessible_children (obj);
   for (i = 0; i < n_children; i++)
-  {
-    AtkObject* found_obj;
-
-    child = atk_object_ref_accessible_child (obj, i);
-
-    if (child == NULL)
-      continue;
-
-    accessible_name = atk_object_get_name (child);
-    if (accessible_name && (g_strcasecmp(name, accessible_name) == 0))
     {
-      for (j=0; j < num_roles; j++)
-      {
-        if (atk_object_get_role (child) == roles[j])
-          return child;
-      }
+      AtkObject* found_obj;
+
+      child = atk_object_ref_accessible_child (obj, i);
+
+      if (child == NULL)
+        continue;
+
+      accessible_name = atk_object_get_name (child);
+      if (accessible_name && (g_strcasecmp(name, accessible_name) == 0))
+        {
+          for (j=0; j < num_roles; j++)
+            {
+              if (atk_object_get_role (child) == roles[j])
+                return child;
+            }
+        }
+      found_obj = find_object_by_accessible_name_and_role (child, name, 
+                                                           roles, num_roles);
+      g_object_unref (child);
+      if (found_obj)
+        return found_obj;
     }
-    found_obj = find_object_by_accessible_name_and_role (child, name, 
-                             roles, num_roles);
-    g_object_unref (child);
-    if (found_obj)
-    {
-      return found_obj;
-    }
-  }
   return NULL;
 }
 
@@ -236,7 +231,8 @@ find_object_by_accessible_name_and_role (AtkObject   *obj,
  * if no object is found. 
  */
 AtkObject*
-find_object_by_type (AtkObject *obj, gchar *type)
+find_object_by_type (AtkObject *obj, 
+                     gchar     *type)
 {
   /*
    * Find the first object which is a descendant of the specified object
@@ -259,26 +255,24 @@ find_object_by_type (AtkObject *obj, gchar *type)
 
   n_children = atk_object_get_n_accessible_children (obj);
   for (i = 0; i < n_children; i++)
-  {
-    AtkObject* found_obj;
-
-    child = atk_object_ref_accessible_child (obj, i);
-
-    if (child == NULL)
-      continue;
-
-    typename = g_type_name (G_OBJECT_TYPE (child));
-
-    if (strcmp (typename, type) == 0)
-       return child;
-
-    found_obj = find_object_by_type (child, type);
-    g_object_unref (child);
-    if (found_obj)
     {
-      return found_obj;
+      AtkObject* found_obj;
+
+      child = atk_object_ref_accessible_child (obj, i);
+
+      if (child == NULL)
+        continue;
+
+      typename = g_type_name (G_OBJECT_TYPE (child));
+
+      if (strcmp (typename, type) == 0)
+        return child;
+
+      found_obj = find_object_by_type (child, type);
+      g_object_unref (child);
+      if (found_obj)
+        return found_obj;
     }
-  }
   return NULL;
 }
 
@@ -307,29 +301,24 @@ already_accessed_atk_object (AtkObject *obj)
    * object is destroyed it remains in the array.
    */
   if (obj_array == NULL)
-  {
     obj_array = g_ptr_array_new ();
-  }
 
   for (i = 0; i < obj_array->len; i++)
-  {
-    if (obj == g_ptr_array_index (obj_array, i))
     {
-      found = TRUE;
-      break;
+      if (obj == g_ptr_array_index (obj_array, i))
+        {
+          found = TRUE;
+          break;
+        }
     }
-  }
   if (!found)
-  {
     g_ptr_array_add (obj_array, obj);
-  }
 
   return found;
 }
 
 /* Global list of ATK Role Names */
-#define ATK_NUM_ROLES	69
-static gchar g_role_names[ATK_NUM_ROLES][100] =
+static gchar g_role_names[ATK_ROLE_LAST_DEFINED][100] =
 {
   "ATK_ROLE_INVALID",
   "ATK_ROLE_ACCEL_LABEL",
@@ -396,10 +385,10 @@ static gchar g_role_names[ATK_NUM_ROLES][100] =
   "ATK_ROLE_TOOL_BAR",
   "ATK_ROLE_TOOL_TIP",
   "ATK_ROLE_TREE",
+  "ATK_ROLE_TREE_TABLE",
   "ATK_ROLE_UNKNOWN",
   "ATK_ROLE_VIEWPORT",
-  "ATK_ROLE_WINDOW",
-  "ATK_ROLE_LAST_DEFINED"
+  "ATK_ROLE_WINDOW"
 };
 
 /**
@@ -413,27 +402,8 @@ static gchar g_role_names[ATK_NUM_ROLES][100] =
 gchar *
 get_role_name(AtkRole role)
 {
-  if (role < ATK_NUM_ROLES)
-    return(g_role_names[role]);
-  else
-    return NULL;
-}
-
-static gchar g_relation_names[ATK_RELATION_LAST_DEFINED][100] =
-{
-  "ATK_RELATION_NULL",
-  "ATK_RELATION_CONTROLLED_BY",
-  "ATK_RELATION_CONTROLLER_FOR",
-  "ATK_RELATION_LABEL_FOR",
-  "ATK_RELATION_LABELLED_BY",
-  "ATK_RELATION_MEMBER_OF"
-};
-
-gchar *
-get_relation_name(AtkRelationType relation)
-{
-  if (relation < ATK_RELATION_LAST_DEFINED)
-    return(g_relation_names[relation]);
+  if (role < ATK_ROLE_LAST_DEFINED)
+    return g_role_names[role];
   else
     return NULL;
 }
@@ -447,7 +417,9 @@ get_relation_name(AtkRelationType relation)
  * Displays the hierarchy of widgets starting from @obj.
  **/
 void
-display_children (AtkObject *obj, gint depth, gint child_number)
+display_children (AtkObject *obj, 
+                  gint      depth, 
+                  gint      child_number)
 {
   display_children_to_depth(obj, -1, depth, child_number);
 }
@@ -463,8 +435,10 @@ display_children (AtkObject *obj, gint depth, gint child_number)
  * to the specified depth.
  **/
 void
-display_children_to_depth (AtkObject *obj, gint to_depth,
-  gint depth, gint child_number)
+display_children_to_depth (AtkObject *obj,
+                           gint      to_depth,
+                           gint      depth,
+                           gint      child_number)
 {
   AtkRole role;
   gchar *rolename;
@@ -499,30 +473,29 @@ display_children_to_depth (AtkObject *obj, gint to_depth,
     g_print("role <error>");
 
   if (GTK_IS_ACCESSIBLE(obj))
-  {
-    GtkWidget *widget;
-    widget = GTK_ACCESSIBLE (obj)->widget;
-    g_print("name <%s>, ", gtk_widget_get_name(GTK_WIDGET (widget)));
-  }
+    {
+      GtkWidget *widget;
+
+      widget = GTK_ACCESSIBLE (obj)->widget;
+      g_print("name <%s>, ", gtk_widget_get_name(GTK_WIDGET (widget)));
+    }
   else
-  {
     g_print("name <NULL>, ");
-  }
 
   typename = g_type_name (G_OBJECT_TYPE (obj));
   g_print ("typename <%s>\n", typename);
 
   for (i = 0; i < n_children; i++)
-  {
-    AtkObject *child;
-
-    child = atk_object_ref_accessible_child (obj, i);
-    if (child != NULL)
     {
-      display_children_to_depth (child, to_depth, depth + 1, i);
-      g_object_unref (G_OBJECT (child));
+      AtkObject *child;
+
+      child = atk_object_ref_accessible_child (obj, i);
+      if (child != NULL)
+        {
+          display_children_to_depth (child, to_depth, depth + 1, i);
+          g_object_unref (G_OBJECT (child));
+        }
     }
-  }
 }
 
 /* Test GUI logic */
@@ -589,7 +562,9 @@ static TestCB          testcb[MAX_WINDOWS];
  * Returns: The window number of the created window if successful, -1 otherwise.
  **/
 gint
-create_windows(AtkObject *obj, TLruntest runtest, OutputWindow **outwin)
+create_windows (AtkObject    *obj,
+                TLruntest    runtest,
+                OutputWindow **outwin)
 {
   gboolean valid;  
   gint tmp;
@@ -598,11 +573,11 @@ create_windows(AtkObject *obj, TLruntest runtest, OutputWindow **outwin)
   _create_output_window(outwin); 
   valid = _create_select_tests_window(obj, runtest, outwin);
   if (valid)
-  {
-    tmp = window_no;
-    window_no++;
-    return tmp;
-  }
+    {
+      tmp = window_no;
+      window_no++;
+      return tmp;
+    }
   else
     return -1;
 }
@@ -615,42 +590,42 @@ create_windows(AtkObject *obj, TLruntest runtest, OutputWindow **outwin)
  * Creates the Test Result Output Window .
  **/
 static void
-_create_output_window(OutputWindow **outwin)
+_create_output_window (OutputWindow **outwin)
 {
   GtkWidget *view;
   GtkWidget *scrolled_window;
   OutputWindow *localow;
 
   if (*outwin == NULL)
-  {
-    localow = (OutputWindow *) malloc (sizeof(OutputWindow));
+    {
+      localow = (OutputWindow *) malloc (sizeof(OutputWindow));
    
-    localow->outputBuffer = gtk_text_buffer_new(NULL);
-    view = gtk_text_view_new_with_buffer(GTK_TEXT_BUFFER(localow->outputBuffer));
-    gtk_widget_set_usize(view, 700, 500);
-    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
-    gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);	
+      localow->outputBuffer = gtk_text_buffer_new(NULL);
+      view = gtk_text_view_new_with_buffer(GTK_TEXT_BUFFER(localow->outputBuffer));
+      gtk_widget_set_usize(view, 700, 500);
+      gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
+      gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);	
 
-    localow->outputWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW(localow->outputWindow), "Test Output");
-    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+      localow->outputWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_title(GTK_WINDOW(localow->outputWindow), "Test Output");
+      scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
-      GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_container_add(GTK_CONTAINER(localow->outputWindow), scrolled_window);
-    gtk_container_add(GTK_CONTAINER(scrolled_window), view);
-    gtk_text_buffer_get_iter_at_offset(localow->outputBuffer, &localow->outputIter, 0);
-    gtk_widget_show(view);
-    gtk_widget_show(scrolled_window);
-    gtk_widget_show(localow->outputWindow);
+      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+      gtk_container_add(GTK_CONTAINER(localow->outputWindow), scrolled_window);
+      gtk_container_add(GTK_CONTAINER(scrolled_window), view);
+      gtk_text_buffer_get_iter_at_offset(localow->outputBuffer, &localow->outputIter, 0);
+      gtk_widget_show(view);
+      gtk_widget_show(scrolled_window);
+      gtk_widget_show(localow->outputWindow);
 
-    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(localow->outputBuffer),
-      "\n\nWelcome to the test GUI:\nTest results are printed here\n\n", 58);
-    gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(localow->outputBuffer),
-      &localow->outputIter, 0);
-    *outwin = localow;
-    ow = *outwin;
-  }
+      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(localow->outputBuffer),
+        "\n\nWelcome to the test GUI:\nTest results are printed here\n\n", 58);
+      gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(localow->outputBuffer),
+                                          &localow->outputIter, 0);
+      *outwin = localow;
+      ow = *outwin;
+    }
 }
 
 /** 
@@ -665,61 +640,72 @@ _create_output_window(OutputWindow **outwin)
  * Returns: TRUE if successful, FALSE otherwise
  **/
 static gboolean
-_create_select_tests_window(AtkObject *obj, TLruntest runtest, OutputWindow **outwin)
+_create_select_tests_window (AtkObject    *obj,
+                             TLruntest    runtest,
+                             OutputWindow **outwin)
 {
-     AtkText   *textwidget;
-     GtkWidget *hbuttonbox;
-     GtkWidget *scrolledWindow;
+  AtkText   *textwidget;
+  GtkWidget *hbuttonbox;
+  GtkWidget *scrolledWindow;
 
-     if (window_no >= 0 && window_no < MAX_WINDOWS){
-       md[window_no] = (MainDialog *) malloc (sizeof(MainDialog));
+  if (window_no >= 0 && window_no < MAX_WINDOWS)
+    {
+      md[window_no] = (MainDialog *) malloc (sizeof(MainDialog));
      
-       textwidget = (ATK_TEXT (obj));
+      textwidget = ATK_TEXT (obj);
      
-       /* Setup Window */
-       md[window_no]->selecttestsTitle = "Test Setting";
-       md[window_no]->selecttestsWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-       gtk_window_set_title(GTK_WINDOW(ow->outputWindow), md[window_no]->selecttestsTitle);
-       gtk_window_set_resizable(GTK_WINDOW(md[window_no]->selecttestsWindow), FALSE);
-       gtk_window_set_position(GTK_WINDOW(md[window_no]->selecttestsWindow),
-         GTK_WIN_POS_CENTER); 
-       gtk_signal_connect(GTK_OBJECT(md[window_no]->selecttestsWindow), "destroy",
-         GTK_SIGNAL_FUNC(_destroy), &md[window_no]->selecttestsWindow);
+      /* Setup Window */
+      md[window_no]->selecttestsTitle = "Test Setting";
+      md[window_no]->selecttestsWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_title (GTK_WINDOW( ow->outputWindow),
+                            md[window_no]->selecttestsTitle);
+      gtk_window_set_resizable (GTK_WINDOW(md[window_no]->selecttestsWindow),
+                                FALSE);
+      gtk_window_set_position (GTK_WINDOW(md[window_no]->selecttestsWindow),
+                               GTK_WIN_POS_CENTER); 
+      gtk_signal_connect (GTK_OBJECT(md[window_no]->selecttestsWindow), 
+                          "destroy",
+                          GTK_SIGNAL_FUNC(_destroy), 
+                          &md[window_no]->selecttestsWindow);
      
-       /* Setup Scrolling */
-       scrolledWindow = gtk_scrolled_window_new(NULL, NULL);
-       gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow),
-         GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC); 
-       gtk_widget_set_usize(scrolledWindow, 500, 600);
-       gtk_container_add(GTK_CONTAINER(md[window_no]->selecttestsWindow), scrolledWindow);
+      /* Setup Scrolling */
+      scrolledWindow = gtk_scrolled_window_new(NULL, NULL);
+      gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledWindow),
+                                      GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC); 
+      gtk_widget_set_usize (scrolledWindow, 500, 600);
+      gtk_container_add (GTK_CONTAINER (md[window_no]->selecttestsWindow), 
+                         scrolledWindow);
       
-       /* Setup Layout */
-       md[window_no]->vbox = gtk_vbox_new(TRUE, 0);
-       md[window_no]->button = gtk_button_new_with_mnemonic("_Run Tests");
-       hbuttonbox = gtk_hbutton_box_new();
-       gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox),
-         GTK_BUTTONBOX_SPREAD);
-       gtk_box_pack_end_defaults(GTK_BOX(hbuttonbox), GTK_WIDGET(md[window_no]->button));
-       gtk_box_pack_end_defaults(GTK_BOX(md[window_no]->vbox), hbuttonbox);
-       gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolledWindow),
-       md[window_no]->vbox);
+      /* Setup Layout */
+      md[window_no]->vbox = gtk_vbox_new (TRUE, 0);
+      md[window_no]->button = gtk_button_new_with_mnemonic ("_Run Tests");
+      hbuttonbox = gtk_hbutton_box_new ();
+      gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox),
+                                 GTK_BUTTONBOX_SPREAD);
+      gtk_box_pack_end_defaults (GTK_BOX (hbuttonbox), 
+                                 GTK_WIDGET (md[window_no]->button));
+      gtk_box_pack_end_defaults (GTK_BOX (md[window_no]->vbox), hbuttonbox);
+      gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledWindow),
+                                             md[window_no]->vbox);
 
-       testcb[window_no].runtest = runtest;
-       testcb[window_no].obj = obj;
-       testcb[window_no].win_num = window_no; 
-       gtk_signal_connect(GTK_OBJECT(md[window_no]->button), "clicked",
-         GTK_SIGNAL_FUNC(_testselectioncb),  (gpointer)&testcb[window_no]);
+      testcb[window_no].runtest = runtest;
+      testcb[window_no].obj = obj;
+      testcb[window_no].win_num = window_no; 
+      gtk_signal_connect (GTK_OBJECT (md[window_no]->button), 
+                          "clicked",
+                          GTK_SIGNAL_FUNC (_testselectioncb),  
+                          (gpointer)&testcb[window_no]);
      
-       /* Show all */
-       gtk_widget_grab_focus(md[window_no]->button);
-       gtk_widget_show(md[window_no]->button);
-       gtk_widget_show(hbuttonbox); 
-       gtk_widget_show(scrolledWindow); 
-       gtk_widget_show_all(GTK_WIDGET(md[window_no]->selecttestsWindow));
-       return TRUE;
-     }
-     else
-       return FALSE;
+      /* Show all */
+      gtk_widget_grab_focus (md[window_no]->button);
+      gtk_widget_show (md[window_no]->button);
+      gtk_widget_show (hbuttonbox); 
+      gtk_widget_show (scrolledWindow); 
+      gtk_widget_show_all (GTK_WIDGET (md[window_no]->selecttestsWindow));
+      return TRUE;
+    }
+  else
+    return FALSE;
 }
 
 /** 
@@ -737,54 +723,59 @@ _create_select_tests_window(AtkObject *obj, TLruntest runtest, OutputWindow **ou
  *
  **/
 gboolean
-add_test(gint window, gchar *name, gint num_params, gchar* parameter_names[],
-   gchar* default_names[])
+add_test (gint   window, 
+          gchar  *name,
+          gint   num_params,
+          gchar* parameter_names[],
+          gchar* default_names[])
 {
-     gint i;
+  gint i;
 
-     if (num_params > MAX_PARAMS)
-       return FALSE;
-     else
-     {
-       md[window]->hbox = gtk_hbox_new(FALSE, 0);
-       gtk_box_set_spacing(GTK_BOX(md[window]->hbox), 10);
-       gtk_container_set_border_width(GTK_CONTAINER(md[window]->hbox), 10);
-       gtk_container_add(GTK_CONTAINER(md[window]->vbox), md[window]->hbox);
-       listoftests[window][testcount[window]].toggleButton =
-         gtk_toggle_button_new_with_label(name);
-       gtk_box_pack_start(GTK_BOX(md[window]->hbox),
-         listoftests[window][testcount[window]].toggleButton, FALSE, FALSE, 0);
-       listoftests[window][testcount[window]].testName = name;
-       listoftests[window][testcount[window]].numParameters = num_params;
-       for (i=0; i<num_params; i++) {
-    	  listoftests[window][testcount[window]].parameterLabel[i] =
-            gtk_label_new(parameter_names[i]);
-  	  gtk_box_pack_start(GTK_BOX(md[window]->hbox),
-            listoftests[window][testcount[window]].parameterLabel[i], FALSE, FALSE, 0);
+  if (num_params > MAX_PARAMS)
+    return FALSE;
+  else
+    {
+      md[window]->hbox = gtk_hbox_new (FALSE, 0);
+      gtk_box_set_spacing (GTK_BOX (md[window]->hbox), 10);
+      gtk_container_set_border_width (GTK_CONTAINER (md[window]->hbox), 10);
+      gtk_container_add (GTK_CONTAINER (md[window]->vbox), md[window]->hbox);
+      listoftests[window][testcount[window]].toggleButton =
+         gtk_toggle_button_new_with_label (name);
+      gtk_box_pack_start (GTK_BOX (md[window]->hbox),
+          listoftests[window][testcount[window]].toggleButton, FALSE, FALSE, 0);
+      listoftests[window][testcount[window]].testName = name;
+      listoftests[window][testcount[window]].numParameters = num_params;
+      for (i=0; i<num_params; i++) 
+        {
+     	  listoftests[window][testcount[window]].parameterLabel[i] =
+            gtk_label_new (parameter_names[i]);
+          gtk_box_pack_start (GTK_BOX (md[window]->hbox),
+          listoftests[window][testcount[window]].parameterLabel[i], FALSE, FALSE, 0);
 	  listoftests[window][testcount[window]].parameterInput[i] = gtk_entry_new();
-          gtk_entry_set_text(GTK_ENTRY(listoftests[window][testcount[window]].parameterInput[i]),
+          gtk_entry_set_text (GTK_ENTRY (listoftests[window][testcount[window]].parameterInput[i]),
             default_names[i]);
-          gtk_widget_set_usize(listoftests[window][testcount[window]].parameterInput[i], 50, 22);
-	  gtk_box_pack_start(GTK_BOX(md[window]->hbox),
+          gtk_widget_set_usize (listoftests[window][testcount[window]].parameterInput[i], 50, 22);
+	  gtk_box_pack_start (GTK_BOX (md[window]->hbox),
             listoftests[window][testcount[window]].parameterInput[i], FALSE, FALSE, 0);
-          gtk_widget_set_sensitive(
-            GTK_WIDGET(listoftests[window][testcount[window]].parameterLabel[i]), FALSE);
-          gtk_widget_set_sensitive(
-            GTK_WIDGET(listoftests[window][testcount[window]].parameterInput[i]), FALSE);
-	  gtk_widget_show(listoftests[window][testcount[window]].parameterLabel[i]);
-	  gtk_widget_show(listoftests[window][testcount[window]].parameterInput[i]);
-       }
-       gtk_signal_connect(GTK_OBJECT(listoftests[window][testcount[window]].toggleButton),
-         "toggled", GTK_SIGNAL_FUNC(_toggle_selectedcb),
-         (gpointer)&(listoftests[window][testcount[window]]));
-       gtk_widget_show(listoftests[window][testcount[window]].toggleButton);
-       gtk_widget_show(md[window]->hbox);
-       gtk_widget_show(md[window]->vbox);
+          gtk_widget_set_sensitive (
+            GTK_WIDGET (listoftests[window][testcount[window]].parameterLabel[i]), FALSE);
+          gtk_widget_set_sensitive (
+            GTK_WIDGET (listoftests[window][testcount[window]].parameterInput[i]), FALSE);
+	  gtk_widget_show (listoftests[window][testcount[window]].parameterLabel[i]);
+	  gtk_widget_show (listoftests[window][testcount[window]].parameterInput[i]);
+        }
+      gtk_signal_connect (GTK_OBJECT (listoftests[window][testcount[window]].toggleButton),
+                          "toggled", 
+                          GTK_SIGNAL_FUNC(_toggle_selectedcb),
+                          (gpointer)&(listoftests[window][testcount[window]]));
+      gtk_widget_show (listoftests[window][testcount[window]].toggleButton);
+      gtk_widget_show (md[window]->hbox);
+      gtk_widget_show (md[window]->vbox);
 
-       testcount[window]++;
-       counter++;
-       return TRUE;
-     }  
+      testcount[window]++;
+      counter++;
+      return TRUE;
+    }  
 }
 
 /** 
@@ -807,31 +798,29 @@ gchar **tests_set(gint window, int *count)
 
   *count = 0;
   for (i = 0; i < MAX_TESTS; i++)
-  {
-    onTests[window][i] = NULL;
-  }
+      onTests[window][i] = NULL;
 
-  for(i = 0; i < testcount[window]; i++)
-  {
-    nullparam = FALSE;
-    if (GTK_TOGGLE_BUTTON(listoftests[window][i].toggleButton)->active)
+  for (i = 0; i < testcount[window]; i++)
     {
-      num = listoftests[window][i].numParameters;
-      for (j = 0; j < num; j++)
-      {
-        input = gtk_editable_get_chars(
-          GTK_EDITABLE(listoftests[window][i].parameterInput[j]), 0, -1);
+      nullparam = FALSE;
+      if (GTK_TOGGLE_BUTTON(listoftests[window][i].toggleButton)->active)
+        {
+          num = listoftests[window][i].numParameters;
+          for (j = 0; j < num; j++)
+            {
+              input = gtk_editable_get_chars (
+                    GTK_EDITABLE (listoftests[window][i].parameterInput[j]), 0, -1);
 
-        if (input != NULL && (! strcmp(input, "")))
-          nullparam = TRUE;
-      }
-      if (nullparam == FALSE)
-      {
-        onTests[window][*count] = listoftests[window][i].testName;
-        *count = *count + 1; 
-      }
-    }
-  } 
+              if (input != NULL && (! strcmp(input, "")))
+                nullparam = TRUE;
+            } 
+          if (nullparam == FALSE)
+            {
+              onTests[window][*count] = listoftests[window][i].testName;
+              *count = *count + 1; 
+            }
+        }
+    } 
   return onTests[window];
 }
 
@@ -845,17 +834,16 @@ gchar **tests_set(gint window, int *count)
  * Returns: the position in listoftests[] of @the_test_name
  **/
 static gint
-_get_position_in_array(gint window, gchar *the_test_name)
+_get_position_in_array(gint  window,
+                       gchar *the_test_name)
 {
   gint        i;
   
   for (i = 0; i < testcount[window]; i++)
-  {
-    if (strcmp(listoftests[window][i].testName, the_test_name) == 0)
     {
-      return i;
+      if (strcmp(listoftests[window][i].testName, the_test_name) == 0)
+        return i;
     }
-  }
   return -1;
 }
 
@@ -871,19 +859,21 @@ _get_position_in_array(gint window, gchar *the_test_name)
  * listoftests[]) of @label 
  **/
 static gint
-_get_position_in_parameters(gint window, gchar *label, gint position)
+_get_position_in_parameters(gint  window,
+                            gchar *label,
+                            gint  position)
 {
   gint                    i;
   G_CONST_RETURN gchar    *label_string;
   
   for (i = 0; i < MAX_PARAMS; i++)
-  {
-    label_string = gtk_label_get_text(
-      GTK_LABEL(listoftests[window][position].parameterLabel[i]));
+    {
+      label_string = gtk_label_get_text( 
+               GTK_LABEL (listoftests[window][position].parameterLabel[i]));
 
-    if (strcmp(label_string, label) == 0)
-      return i;
-  }
+      if (strcmp(label_string, label) == 0)
+        return i;
+    }
   return -1;
 }
 
@@ -896,10 +886,10 @@ _get_position_in_parameters(gint window, gchar *label, gint position)
 void
 set_output_buffer(gchar *output)
 {
-  gtk_text_buffer_insert(GTK_TEXT_BUFFER(ow->outputBuffer),
-    &ow->outputIter, output, strlen(output));
-  gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(ow->outputBuffer),
-    &ow->outputIter, 0);
+  gtk_text_buffer_insert (GTK_TEXT_BUFFER (ow->outputBuffer),
+                          &ow->outputIter, output, strlen(output));
+  gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (ow->outputBuffer),
+                                      &ow->outputIter, 0);
 }
 
 /**
@@ -928,8 +918,10 @@ isVisibleDialog()
  *
  * Returns: the user input associated with the @function_name and @arg_label.
  **/
-gchar
-*get_arg_of_func(gint window, gchar *function_name, gchar *arg_label)
+gchar*
+get_arg_of_func (gint  window,
+                 gchar *function_name,
+                 gchar *arg_label)
 {
   G_CONST_RETURN gchar       *argString;
   gchar                      *retString;
@@ -938,26 +930,26 @@ gchar
   position =  _get_position_in_array(window, function_name);
 
   if (position == -1)
-  {
-    g_print("No such function\n");
-    return NULL;
-  }
+    {
+      g_print("No such function\n");
+      return NULL;
+    }
 
   paramPosition = _get_position_in_parameters(window, arg_label, position);
 
   if (paramPosition == -1)
-  {
-    g_print("No such parameter Label\n");
-    return NULL;
-  }
+    {
+      g_print("No such parameter Label\n");
+      return NULL;
+    }
 
   if (position != -1 && paramPosition != -1)
-  {
-    argString = gtk_editable_get_chars(
-      GTK_EDITABLE(listoftests[window][position].parameterInput[paramPosition]),
+    {
+      argString = gtk_editable_get_chars (
+        GTK_EDITABLE (listoftests[window][position].parameterInput[paramPosition]),
       0, -1);
-    retString = g_strdup(argString);
-  }
+      retString = g_strdup(argString);
+    }
 
   return retString;
 }
@@ -978,14 +970,13 @@ string_to_int (char *the_string)
   int int_ret_val; 
 
   while (1)
-  {
-    ret_val = strtod(the_string, &end_ptr);
-    if (*end_ptr == '\0'){
-      break;
+    {
+      ret_val = strtod( the_string, &end_ptr);
+      if (*end_ptr == '\0')
+        break;
+      else
+        printf("\nError: input must be a number\n");
     }
-    else
-      printf("\nError: input must be a number\n");
-  }
    
   int_ret_val = (int) ret_val;
   return (int_ret_val);
@@ -999,28 +990,26 @@ string_to_int (char *the_string)
  * Toggle Button Callback, activating the text entry fields 
  **/
 static void
-_toggle_selectedcb(GtkWidget *widget, gpointer test)
+_toggle_selectedcb (GtkWidget *widget,
+                    gpointer  test)
 {
   int i;
   TestList *testlist = (TestList *) test;
   gboolean toggled;
   gboolean sensitive;
-  toggled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+  toggled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   if (toggled)
-  {
     sensitive = TRUE;
-  }
   else
-  {
     sensitive = FALSE;
-  }
+
   for (i=0; i < testlist->numParameters; i++)
-  {
-    gtk_widget_set_sensitive(GTK_WIDGET(testlist->parameterLabel[i]),
-      sensitive);
-    gtk_widget_set_sensitive(GTK_WIDGET(testlist->parameterInput[i]),
-      sensitive);
-  }
+    {
+      gtk_widget_set_sensitive (GTK_WIDGET (testlist->parameterLabel[i]),
+                                sensitive);
+      gtk_widget_set_sensitive (GTK_WIDGET (testlist->parameterInput[i]),
+                                sensitive);
+    }
 }
 
 /* 
@@ -1031,7 +1020,8 @@ _toggle_selectedcb(GtkWidget *widget, gpointer test)
  * Callback for when the "Run Tests" button is pressed 
  **/
 static void
-_testselectioncb(GtkWidget *widget, gpointer data)
+_testselectioncb (GtkWidget *widget,
+                  gpointer data)
 {
   TestCB* local_testcb = (TestCB *)data;
   local_testcb->runtest(local_testcb->obj, local_testcb->win_num);
@@ -1045,7 +1035,8 @@ _testselectioncb(GtkWidget *widget, gpointer data)
  * Destroy Callback.
  **/
 static void
-_destroy (GtkWidget *widget, gpointer data)
+_destroy (GtkWidget *widget,
+          gpointer  data)
 {
   gtk_main_quit();
 }
